@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-// Copyright (c) 2016, 2022, Oracle and/or its affiliates.
+// Copyright (c) 2016, 2025, Oracle and/or its affiliates.
 //
 // This software is dual-licensed to you under the Universal Permissive License
 // (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
@@ -68,9 +68,9 @@ extern "C" {
 #endif
 
 // define ODPI-C version information
-#define DPI_MAJOR_VERSION   4
+#define DPI_MAJOR_VERSION   5
 #define DPI_MINOR_VERSION   6
-#define DPI_PATCH_LEVEL     0
+#define DPI_PATCH_LEVEL     3
 #define DPI_VERSION_SUFFIX
 
 #define DPI_STR_HELPER(x)       #x
@@ -198,6 +198,7 @@ typedef uint32_t dpiEventType;
 // statement execution modes
 typedef uint32_t dpiExecMode;
 #define DPI_MODE_EXEC_DEFAULT                       0x00000000
+#define DPI_MODE_EXEC_SUSPEND_ON_SUCCESS            0x00000004
 #define DPI_MODE_EXEC_DESCRIBE_ONLY                 0x00000010
 #define DPI_MODE_EXEC_COMMIT_ON_SUCCESS             0x00000020
 #define DPI_MODE_EXEC_BATCH_ERRORS                  0x00000080
@@ -245,6 +246,7 @@ typedef uint32_t dpiNativeTypeNum;
 #define DPI_NATIVE_TYPE_JSON_OBJECT                 3014
 #define DPI_NATIVE_TYPE_JSON_ARRAY                  3015
 #define DPI_NATIVE_TYPE_NULL                        3016
+#define DPI_NATIVE_TYPE_VECTOR                      3017
 
 // operation codes (database change and continuous query notification)
 typedef uint32_t dpiOpCode;
@@ -291,7 +293,10 @@ typedef uint32_t dpiOracleTypeNum;
 #define DPI_ORACLE_TYPE_JSON_ARRAY                  2029
 #define DPI_ORACLE_TYPE_UROWID                      2030
 #define DPI_ORACLE_TYPE_LONG_NVARCHAR               2031
-#define DPI_ORACLE_TYPE_MAX                         2032
+#define DPI_ORACLE_TYPE_XMLTYPE                     2032
+#define DPI_ORACLE_TYPE_VECTOR                      2033
+#define DPI_ORACLE_TYPE_JSON_ID                     2034
+#define DPI_ORACLE_TYPE_MAX                         2035
 
 // session pool close modes
 typedef uint32_t dpiPoolCloseMode;
@@ -332,6 +337,13 @@ typedef uint32_t dpiStartupMode;
 #define DPI_MODE_STARTUP_FORCE                      1
 #define DPI_MODE_STARTUP_RESTRICT                   2
 
+// server types
+typedef uint8_t dpiServerType;
+#define DPI_SERVER_TYPE_UNKNOWN                     0
+#define DPI_SERVER_TYPE_DEDICATED                   1
+#define DPI_SERVER_TYPE_SHARED                      2
+#define DPI_SERVER_TYPE_POOLED                      4
+
 // statement types
 typedef uint16_t dpiStatementType;
 #define DPI_STMT_TYPE_UNKNOWN                       0
@@ -391,6 +403,18 @@ typedef uint32_t dpiTpcEndFlags;
 #define DPI_TPC_END_NORMAL                          0
 #define DPI_TPC_END_SUSPEND                         0x00100000
 
+// vector flags
+typedef uint8_t dpiVectorFlags;
+#define DPI_VECTOR_FLAGS_FLEXIBLE_DIM               0x01
+#define DPI_VECTOR_FLAGS_SPARSE                     0x02
+
+// vector formats
+typedef uint8_t dpiVectorFormat;
+#define DPI_VECTOR_FORMAT_FLOAT32                   2
+#define DPI_VECTOR_FORMAT_FLOAT64                   3
+#define DPI_VECTOR_FORMAT_INT8                      4
+#define DPI_VECTOR_FORMAT_BINARY                    5
+
 // visibility of messages in advanced queuing
 typedef uint32_t dpiVisibility;
 #define DPI_VISIBILITY_IMMEDIATE                    1
@@ -421,15 +445,18 @@ typedef struct dpiSodaDocCursor dpiSodaDocCursor;
 typedef struct dpiStmt dpiStmt;
 typedef struct dpiSubscr dpiSubscr;
 typedef struct dpiVar dpiVar;
+typedef struct dpiVector dpiVector;
 
 
 //-----------------------------------------------------------------------------
 // Forward Declarations of Other Types
 //-----------------------------------------------------------------------------
 typedef struct dpiAccessToken dpiAccessToken;
+typedef struct dpiAnnotation dpiAnnotation;
 typedef struct dpiAppContext dpiAppContext;
 typedef struct dpiCommonCreateParams dpiCommonCreateParams;
 typedef struct dpiConnCreateParams dpiConnCreateParams;
+typedef struct dpiConnInfo dpiConnInfo;
 typedef struct dpiContextCreateParams dpiContextCreateParams;
 typedef struct dpiData dpiData;
 typedef union dpiDataBuffer dpiDataBuffer;
@@ -442,15 +469,19 @@ typedef struct dpiObjectAttrInfo dpiObjectAttrInfo;
 typedef struct dpiObjectTypeInfo dpiObjectTypeInfo;
 typedef struct dpiPoolCreateParams dpiPoolCreateParams;
 typedef struct dpiQueryInfo dpiQueryInfo;
+typedef struct dpiSessionlessTransactionId dpiSessionlessTransactionId;
 typedef struct dpiShardingKeyColumn dpiShardingKeyColumn;
-typedef struct dpiSodaCollNames dpiSodaCollNames;
+typedef struct dpiStringList dpiSodaCollNames;
 typedef struct dpiSodaOperOptions dpiSodaOperOptions;
 typedef struct dpiStmtInfo dpiStmtInfo;
+typedef struct dpiStringList dpiStringList;
 typedef struct dpiSubscrCreateParams dpiSubscrCreateParams;
 typedef struct dpiSubscrMessage dpiSubscrMessage;
 typedef struct dpiSubscrMessageQuery dpiSubscrMessageQuery;
 typedef struct dpiSubscrMessageRow dpiSubscrMessageRow;
 typedef struct dpiSubscrMessageTable dpiSubscrMessageTable;
+typedef struct dpiVectorInfo dpiVectorInfo;
+typedef union dpiVectorDimensionBuffer dpiVectorDimensionBuffer;
 typedef struct dpiVersionInfo dpiVersionInfo;
 typedef struct dpiXid dpiXid;
 
@@ -552,6 +583,15 @@ union dpiDataBuffer {
     dpiObject *asObject;
     dpiStmt *asStmt;
     dpiRowid *asRowid;
+    dpiVector *asVector;
+};
+
+// structure used for annotations
+struct dpiAnnotation {
+    const char *key;
+    uint32_t keyLength;
+    const char *value;
+    uint32_t valueLength;
 };
 
 // structure used for application context
@@ -605,13 +645,30 @@ struct dpiConnCreateParams {
     int outNewSession;
 };
 
-// structure used for creating connections
+// structure used for transferring connection information from ODPI-C
+struct dpiConnInfo {
+    const char *dbDomain;
+    uint32_t dbDomainLength;
+    const char *dbName;
+    uint32_t dbNameLength;
+    const char *instanceName;
+    uint32_t instanceNameLength;
+    const char *serviceName;
+    uint32_t serviceNameLength;
+    uint32_t maxIdentifierLength;
+    uint32_t maxOpenCursors;
+    uint8_t serverType;
+};
+
+// structure used for creating a context
 struct dpiContextCreateParams {
     const char *defaultDriverName;
     const char *defaultEncoding;
     const char *loadErrorUrl;
     const char *oracleClientLibDir;
     const char *oracleClientConfigDir;
+    int sodaUseJsonDesc;
+    int useJsonId;
 };
 
 // structure used for transferring data to/from ODPI-C
@@ -632,6 +689,17 @@ struct dpiDataTypeInfo {
     int8_t scale;
     uint8_t fsPrecision;
     dpiObjectType *objectType;
+    int isJson;
+    const char *domainSchema;
+    uint32_t domainSchemaLength;
+    const char *domainName;
+    uint32_t domainNameLength;
+    uint32_t numAnnotations;
+    dpiAnnotation *annotations;
+    int isOson;
+    uint32_t vectorDimensions;
+    uint8_t vectorFormat;
+    uint8_t vectorFlags;
 };
 
 // structure used for storing token authentication data
@@ -721,6 +789,12 @@ struct dpiMsgRecipient {
     uint32_t nameLength;
 };
 
+// structure used for storing sessionless transaction ids
+struct dpiSessionlessTransactionId {
+    char value[64];
+    uint32_t length;
+};
+
 // structure used for sharding key columns
 struct dpiShardingKeyColumn {
     dpiOracleTypeNum oracleTypeNum;
@@ -728,11 +802,22 @@ struct dpiShardingKeyColumn {
     dpiDataBuffer value;
 };
 
-// structure used for getting collection names from the database
-struct dpiSodaCollNames {
-    uint32_t numNames;
-    const char **names;
-    uint32_t *nameLengths;
+// structure used for getting an array of strings from the database; the unions
+// are for aliases for the names used when the structure was called
+// dpiSodaCollNames instead
+struct dpiStringList {
+    union {
+        uint32_t numStrings;
+        uint32_t numNames;
+    };
+    union {
+        const char **strings;
+        const char **names;
+    };
+    union {
+        uint32_t *stringLengths;
+        uint32_t *nameLengths;
+    };
 };
 
 // structure used for SODA operations (find/replace/remove)
@@ -751,6 +836,7 @@ struct dpiSodaOperOptions {
     uint32_t fetchArraySize;
     const char *hint;
     uint32_t hintLength;
+    int lock;
 };
 
 // structure used for transferring statement information from ODPI-C
@@ -761,6 +847,8 @@ struct dpiStmtInfo {
     int isDML;
     dpiStatementType statementType;
     int isReturning;
+    char *sqlId;
+    uint32_t sqlIdLength;
 };
 
 // callback for subscriptions
@@ -847,6 +935,25 @@ struct dpiVersionInfo {
     uint32_t fullVersionNum;
 };
 
+// union used for providing a buffer for vector dimensions
+union dpiVectorDimensionBuffer {
+    void* asPtr;
+    int8_t* asInt8;
+    float* asFloat;
+    double* asDouble;
+
+};
+
+// structure used for transferring vector information
+struct dpiVectorInfo {
+    uint8_t format;
+    uint32_t numDimensions;
+    uint8_t dimensionSize;
+    dpiVectorDimensionBuffer dimensions;
+    uint32_t numSparseValues;
+    uint32_t *sparseIndices;
+};
+
 // structure used for defining two-phase commit transaction ids (XIDs)
 struct dpiXid {
     long formatId;
@@ -874,6 +981,10 @@ DPI_EXPORT int dpiContext_createWithParams(unsigned int majorVersion,
 // destroy context handle
 DPI_EXPORT int dpiContext_destroy(dpiContext *context);
 
+// free string list contents
+DPI_EXPORT int dpiContext_freeStringList(dpiContext *context,
+        dpiStringList *list);
+
 // return the OCI client version in use
 DPI_EXPORT int dpiContext_getClientVersion(const dpiContext *context,
         dpiVersionInfo *versionInfo);
@@ -910,12 +1021,6 @@ DPI_EXPORT int dpiContext_initSubscrCreateParams(const dpiContext *context,
 // add a reference to a connection
 DPI_EXPORT int dpiConn_addRef(dpiConn *conn);
 
-// begin a distributed transaction
-// DEPRECATED: use dpiConn_tpcBegin() instead
-DPI_EXPORT int dpiConn_beginDistribTrans(dpiConn *conn, long formatId,
-        const char *globalTransactionId, uint32_t globalTransactionIdLength,
-        const char *branchQualifier, uint32_t branchQualifierLength);
-
 // break execution of the statement running on the connection
 DPI_EXPORT int dpiConn_breakExecution(dpiConn *conn);
 
@@ -956,6 +1061,14 @@ DPI_EXPORT int dpiConn_getCallTimeout(dpiConn *conn, uint32_t *value);
 DPI_EXPORT int dpiConn_getCurrentSchema(dpiConn *conn, const char **value,
         uint32_t *valueLength);
 
+// get database domain name
+DPI_EXPORT int dpiConn_getDbDomain(dpiConn *conn, const char **value,
+        uint32_t *valueLength);
+
+// get database name
+DPI_EXPORT int dpiConn_getDbName(dpiConn *conn, const char **value,
+        uint32_t *valueLength);
+
 // get edition associated with the connection
 DPI_EXPORT int dpiConn_getEdition(dpiConn *conn, const char **value,
         uint32_t *valueLength);
@@ -970,6 +1083,13 @@ DPI_EXPORT int dpiConn_getExternalName(dpiConn *conn, const char **value,
 // get the OCI service context handle associated with the connection
 DPI_EXPORT int dpiConn_getHandle(dpiConn *conn, void **handle);
 
+// return information about the connection
+DPI_EXPORT int dpiConn_getInfo(dpiConn *conn, dpiConnInfo *info);
+
+// get instance name associated with the connection
+DPI_EXPORT int dpiConn_getInstanceName(dpiConn *conn, const char **value,
+        uint32_t *valueLength);
+
 // get internal name associated with the connection
 DPI_EXPORT int dpiConn_getInternalName(dpiConn *conn, const char **value,
         uint32_t *valueLength);
@@ -981,6 +1101,10 @@ DPI_EXPORT int dpiConn_getIsHealthy(dpiConn *conn, int *isHealthy);
 DPI_EXPORT int dpiConn_getLTXID(dpiConn *conn, const char **value,
         uint32_t *valueLength);
 
+// get the maximum number of open cursors allowed by the database
+DPI_EXPORT int dpiConn_getMaxOpenCursors(dpiConn *conn,
+        uint32_t *maxOpenCursors);
+
 // create a new object type and return it for subsequent object creation
 DPI_EXPORT int dpiConn_getObjectType(dpiConn *conn, const char *name,
         uint32_t nameLength, dpiObjectType **objType);
@@ -995,12 +1119,20 @@ DPI_EXPORT int dpiConn_getServerVersion(dpiConn *conn,
         const char **releaseString, uint32_t *releaseStringLength,
         dpiVersionInfo *versionInfo);
 
+// get the service name used to connect to the database
+DPI_EXPORT int dpiConn_getServiceName(dpiConn *conn, const char **value,
+        uint32_t *valueLength);
+
 // get SODA interface object
 DPI_EXPORT int dpiConn_getSodaDb(dpiConn *conn, dpiSodaDb **db);
 
 // return the statement cache size
 DPI_EXPORT int dpiConn_getStmtCacheSize(dpiConn *conn, uint32_t *cacheSize);
 
+// get whether or not a transaction is in progress
+DPI_EXPORT int dpiConn_getTransactionInProgress(dpiConn *conn,
+        int *txnInProgress);
+
 // create a new dequeue options object and return it
 DPI_EXPORT int dpiConn_newDeqOptions(dpiConn *conn, dpiDeqOptions **options);
 
@@ -1031,13 +1163,13 @@ DPI_EXPORT int dpiConn_newVar(dpiConn *conn, dpiOracleTypeNum oracleTypeNum,
         int sizeIsBytes, int isArray, dpiObjectType *objType, dpiVar **var,
         dpiData **data);
 
+// create a new vector
+DPI_EXPORT int dpiConn_newVector(dpiConn *conn, dpiVectorInfo *info,
+        dpiVector **vector);
+
 // ping the connection to see if it is still alive
 DPI_EXPORT int dpiConn_ping(dpiConn *conn);
 
-// prepare a distributed transaction for commit
-// DEPRECATED: use dpiConn_tpcPrepare() instead
-DPI_EXPORT int dpiConn_prepareDistribTrans(dpiConn *conn, int *commitNeeded);
-
 // prepare a statement and return it for subsequent execution/fetching
 DPI_EXPORT int dpiConn_prepareStmt(dpiConn *conn, int scrollable,
         const char *sql, uint32_t sqlLength, const char *tag,
@@ -1133,6 +1265,18 @@ DPI_EXPORT int dpiConn_tpcRollback(dpiConn *conn, dpiXid *xid);
 // unsubscribe from events in the database
 DPI_EXPORT int dpiConn_unsubscribe(dpiConn *conn, dpiSubscr *subscr);
 
+// start a sessionless transaction
+DPI_EXPORT int dpiConn_beginSessionlessTransaction(dpiConn *conn,
+        dpiSessionlessTransactionId* transactionId, uint32_t timeout,
+        int deferRoundTrip);
+
+// resume a sessionless transaction
+DPI_EXPORT int dpiConn_resumeSessionlessTransaction(dpiConn *conn,
+        dpiSessionlessTransactionId* transactionId, uint32_t timeout,
+        int deferRoundTrip);
+
+// suspend a sessionless transaction
+DPI_EXPORT int dpiConn_suspendSessionlessTransaction(dpiConn *conn);
 
 //-----------------------------------------------------------------------------
 // Data Methods (dpiData)
@@ -1186,6 +1330,9 @@ DPI_EXPORT dpiTimestamp *dpiData_getTimestamp(dpiData *data);
 // return the unsigned integer portion of the data
 DPI_EXPORT uint64_t dpiData_getUint64(dpiData *data);
 
+// return the VECTOR portion of the data
+DPI_EXPORT dpiVector *dpiData_getVector(dpiData *data);
+
 // set the boolean portion of the data
 DPI_EXPORT void dpiData_setBool(dpiData *data, int value);
 
@@ -1203,7 +1350,7 @@ DPI_EXPORT void dpiData_setInt64(dpiData *data, int64_t value);
 
 // set the interval (days/seconds) portion of the data
 DPI_EXPORT void dpiData_setIntervalDS(dpiData *data, int32_t days,
-        int32_t hours, int32_t minutes, int32_t seconds, int32_t fsceconds);
+        int32_t hours, int32_t minutes, int32_t seconds, int32_t fseconds);
 
 // set the interval (years/months) portion of the data
 DPI_EXPORT void dpiData_setIntervalYM(dpiData *data, int32_t years,
@@ -1813,6 +1960,10 @@ DPI_EXPORT int dpiSodaColl_insertOneWithOptions(dpiSodaColl *coll,
         dpiSodaDoc *doc, dpiSodaOperOptions *options, uint32_t flags,
         dpiSodaDoc **insertedDoc);
 
+// get a list of indexes associated with the collection
+DPI_EXPORT int dpiSodaColl_listIndexes(dpiSodaColl *coll, uint32_t flags,
+        dpiStringList *list);
+
 // release a reference to the SODA collection
 DPI_EXPORT int dpiSodaColl_release(dpiSodaColl *coll);
 
@@ -1867,15 +2018,20 @@ DPI_EXPORT int dpiSodaDb_createCollection(dpiSodaDb *db, const char *name,
         uint32_t nameLength, const char *metadata, uint32_t metadataLength,
         uint32_t flags, dpiSodaColl **coll);
 
-// create a new SODA document
+// create a new SODA document with binary or encoded text content
 DPI_EXPORT int dpiSodaDb_createDocument(dpiSodaDb *db, const char *key,
         uint32_t keyLength, const char *content, uint32_t contentLength,
         const char *mediaType, uint32_t mediaTypeLength, uint32_t flags,
         dpiSodaDoc **doc);
 
+// create a new SODA document with JSON content
+DPI_EXPORT int dpiSodaDb_createJsonDocument(dpiSodaDb *db, const char *key,
+        uint32_t keyLength, const dpiJsonNode *content, uint32_t flags,
+        dpiSodaDoc **doc);
+
 // free the memory allocated when getting an array of SODA collection names
 DPI_EXPORT int dpiSodaDb_freeCollectionNames(dpiSodaDb *db,
-        dpiSodaCollNames *names);
+        dpiStringList *names);
 
 // return a cursor to iterate over SODA collections
 DPI_EXPORT int dpiSodaDb_getCollections(dpiSodaDb *db, const char *startName,
@@ -1884,7 +2040,7 @@ DPI_EXPORT int dpiSodaDb_getCollections(dpiSodaDb *db, const char *startName,
 // return an array of SODA collection names
 DPI_EXPORT int dpiSodaDb_getCollectionNames(dpiSodaDb *db,
         const char *startName, uint32_t startNameLength, uint32_t limit,
-        uint32_t flags, dpiSodaCollNames *names);
+        uint32_t flags, dpiStringList *names);
 
 // open an existing SODA collection
 DPI_EXPORT int dpiSodaDb_openCollection(dpiSodaDb *db, const char *name,
@@ -1901,7 +2057,7 @@ DPI_EXPORT int dpiSodaDb_release(dpiSodaDb *db);
 // add a reference to the SODA document
 DPI_EXPORT int dpiSodaDoc_addRef(dpiSodaDoc *cursor);
 
-// get the content of the document
+// get the binary or encoded text content of the document
 DPI_EXPORT int dpiSodaDoc_getContent(dpiSodaDoc *doc, const char **value,
         uint32_t *valueLength, const char **encoding);
 
@@ -1909,6 +2065,12 @@ DPI_EXPORT int dpiSodaDoc_getContent(dpiSodaDoc *doc, const char **value,
 DPI_EXPORT int dpiSodaDoc_getCreatedOn(dpiSodaDoc *doc, const char **value,
         uint32_t *valueLength);
 
+// get whether the document contains a JSON document or not
+DPI_EXPORT int dpiSodaDoc_getIsJson(dpiSodaDoc *doc, int *isJson);
+
+// get the JSON content of the document
+DPI_EXPORT int dpiSodaDoc_getJsonContent(dpiSodaDoc *doc, dpiJson **value);
+
 // get the key associated with the document
 DPI_EXPORT int dpiSodaDoc_getKey(dpiSodaDoc *doc, const char **value,
         uint32_t *valueLength);
@@ -2165,9 +2327,29 @@ DPI_EXPORT int dpiVar_setFromRowid(dpiVar *var, uint32_t pos, dpiRowid *rowid);
 // set the value of the variable from a statement
 DPI_EXPORT int dpiVar_setFromStmt(dpiVar *var, uint32_t pos, dpiStmt *stmt);
 
+// set the value of the variable from a vector
+DPI_EXPORT int dpiVar_setFromVector(dpiVar *var, uint32_t pos,
+        dpiVector *vector);
+
 // set the number of elements in a PL/SQL index-by table
 DPI_EXPORT int dpiVar_setNumElementsInArray(dpiVar *var, uint32_t numElements);
 
+//-----------------------------------------------------------------------------
+// Vector Methods (dpiVector)
+//-----------------------------------------------------------------------------
+
+// add a reference to the vector
+DPI_EXPORT int dpiVector_addRef(dpiVector *vector);
+
+// get information about the vector
+DPI_EXPORT int dpiVector_getValue(dpiVector *vector, dpiVectorInfo *info);
+
+// release a reference to the vector
+DPI_EXPORT int dpiVector_release(dpiVector *vector);
+
+// set the contents of the vector
+DPI_EXPORT int dpiVector_setValue(dpiVector *vector, dpiVectorInfo *info);
+
 #ifdef __cplusplus
 }
 #endif
