@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-// Copyright (c) 2016, 2022, Oracle and/or its affiliates.
+// Copyright (c) 2016, 2025, Oracle and/or its affiliates.
 //
 // This software is dual-licensed to you under the Universal Permissive License
 // (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
@@ -280,6 +280,7 @@ static void dpiStmt__clearBindVars(dpiStmt *stmt, dpiError *error)
 //-----------------------------------------------------------------------------
 static void dpiStmt__clearQueryVars(dpiStmt *stmt, dpiError *error)
 {
+    dpiDataTypeInfo *typeInfo;
     uint32_t i;
 
     if (stmt->queryVars) {
@@ -288,10 +289,14 @@ static void dpiStmt__clearQueryVars(dpiStmt *stmt, dpiError *error)
                 dpiGen__setRefCount(stmt->queryVars[i], error, -1);
                 stmt->queryVars[i] = NULL;
             }
-            if (stmt->queryInfo[i].typeInfo.objectType) {
-                dpiGen__setRefCount(stmt->queryInfo[i].typeInfo.objectType,
-                        error, -1);
-                stmt->queryInfo[i].typeInfo.objectType = NULL;
+            typeInfo = &stmt->queryInfo[i].typeInfo;
+            if (typeInfo->objectType) {
+                dpiGen__setRefCount(typeInfo->objectType, error, -1);
+                typeInfo->objectType = NULL;
+            }
+            if (typeInfo->annotations) {
+                dpiUtils__freeMemory(typeInfo->annotations);
+                typeInfo->annotations = NULL;
             }
         }
         dpiUtils__freeMemory(stmt->queryVars);
@@ -567,10 +572,11 @@ static int dpiStmt__define(dpiStmt *stmt, uint32_t pos, dpiVar *var,
 static int dpiStmt__execute(dpiStmt *stmt, uint32_t numIters,
         uint32_t mode, int reExecute, dpiError *error)
 {
+    uint32_t i, j, temp, sqlIdLength;
     uint16_t tempOffset;
-    uint32_t i, j, temp;
     dpiData *data;
     dpiVar *var;
+    char *sqlId;
 
     // for all bound variables, transfer data from dpiData structure to Oracle
     // buffer structures
@@ -608,17 +614,27 @@ static int dpiStmt__execute(dpiStmt *stmt, uint32_t numIters,
     if (stmt->scrollable)
         mode |= DPI_OCI_STMT_SCROLLABLE_READONLY;
 
+    // if requested, suspend the sessionless transaction after the call
+    // completes successfully
+    if (mode & DPI_MODE_EXEC_SUSPEND_ON_SUCCESS) {
+        if (dpiConn__suspendSessionlessTransaction(stmt->conn,
+                DPI_OCI_SUSPEND_POST_CALL, error) < 0)
+            return DPI_FAILURE;
+    }
+
     // perform execution
-    // re-execute statement for ORA-01007: variable not in select list
-    // drop statement from cache for all errors (except those which are due to
-    // invalid data which may be fixed in subsequent execution)
+    // re-execute statement for ORA-01007: variable not in select list and
+    // ORA-00932: inconsistent data types; drop statement from cache for all
+    // errors (except those which are due to invalid data which may be fixed in
+    // subsequent execution)
     if (dpiOci__stmtExecute(stmt, numIters, mode, error) < 0) {
         dpiOci__attrGet(stmt->handle, DPI_OCI_HTYPE_STMT, &tempOffset, 0,
                 DPI_OCI_ATTR_PARSE_ERROR_OFFSET, "set parse offset", error);
         error->buffer->offset = tempOffset;
         switch (error->buffer->code) {
+            case 932:
             case 1007:
-                if (reExecute)
+                if (reExecute && stmt->statementType == DPI_STMT_TYPE_SELECT)
                     return dpiStmt__reExecute(stmt, numIters, mode, error);
                 stmt->deleteFromCache = 1;
                 break;
@@ -637,6 +653,25 @@ static int dpiStmt__execute(dpiStmt *stmt, uint32_t numIters,
         return DPI_FAILURE;
     }
 
+    // if requested, the sessionless transaction would have been suspended so
+    // clear the transaction now
+    if (mode & DPI_MODE_EXEC_SUSPEND_ON_SUCCESS) {
+        if (dpiConn__clearTransaction(stmt->conn, error) < 0)
+            return DPI_FAILURE;
+    }
+
+    // fetch SQL_ID, if applicable
+    if (dpiUtils__checkClientVersion(stmt->env->versionInfo, 12, 2,
+            NULL) == DPI_SUCCESS) {
+        if (dpiOci__attrGet(stmt->handle, DPI_OCI_HTYPE_STMT, &sqlId,
+                &sqlIdLength, DPI_OCI_ATTR_SQL_ID, "get SQL_ID", error) < 0)
+            return DPI_FAILURE;
+        if (sqlIdLength > sizeof(stmt->sqlId))
+            sqlIdLength = sizeof(stmt->sqlId);
+        memcpy(stmt->sqlId, sqlId, sqlIdLength);
+        stmt->sqlIdLength = sqlIdLength;
+    }
+
     // for queries, disable prefetch for subsequent fetches in order to avoid
     // the overhead of copying from prefetch buffers to our own buffers
     if (stmt->statementType == DPI_STMT_TYPE_SELECT) {
@@ -1271,6 +1306,7 @@ int dpiStmt_execute(dpiStmt *stmt, dpiExecMode mode, uint32_t *numQueryColumns)
         return dpiGen__endPublicFn(stmt, DPI_FAILURE, &error);
     if (numQueryColumns)
         *numQueryColumns = stmt->numQueryVars;
+
     return dpiGen__endPublicFn(stmt, DPI_SUCCESS, &error);
 }
 
@@ -1594,6 +1630,13 @@ int dpiStmt_getInfo(dpiStmt *stmt, dpiStmtInfo *info)
             stmt->statementType == DPI_STMT_TYPE_MERGE);
     info->statementType = stmt->statementType;
     info->isReturning = stmt->isReturning;
+    if (stmt->env->context->dpiMinorVersion > 5) {
+        info->sqlId = stmt->sqlId;
+        info->sqlIdLength = stmt->sqlIdLength;
+    } else {
+        info->sqlId = NULL;
+        info->sqlIdLength = 0;
+    }
     return dpiGen__endPublicFn(stmt, DPI_SUCCESS, &error);
 }
 
@@ -1720,7 +1763,17 @@ int dpiStmt_getQueryInfo(dpiStmt *stmt, uint32_t pos, dpiQueryInfo *info)
     }
 
     // copy query information from internal cache
-    memcpy(info, &stmt->queryInfo[pos - 1], sizeof(dpiQueryInfo));
+    // the size of the dpiDataTypeInfo structure changed in version 5.1 and
+    // again in 5.2; this check and memcpy() for older versions can be removed
+    // once 6.0 is released
+    if (stmt->env->context->dpiMinorVersion > 1) {
+        memcpy(info, &stmt->queryInfo[pos - 1], sizeof(dpiQueryInfo));
+    } else if (stmt->env->context->dpiMinorVersion == 1) {
+        memcpy(info, &stmt->queryInfo[pos - 1], sizeof(dpiQueryInfo__v51));
+    } else {
+        memcpy(info, &stmt->queryInfo[pos - 1], sizeof(dpiQueryInfo__v50));
+    }
+
     return dpiGen__endPublicFn(stmt, DPI_SUCCESS, &error);
 }
 
