@@ -1,12 +1,25 @@
 //-----------------------------------------------------------------------------
-// Copyright (c) 2019, 2021, Oracle and/or its affiliates. All rights reserved.
-// This program is free software: you can modify it and/or redistribute it
-// under the terms of:
+// Copyright (c) 2019, 2025, Oracle and/or its affiliates.
 //
-// (i)  the Universal Permissive License v 1.0 or at your option, any
-//      later version (http://oss.oracle.com/licenses/upl); and/or
+// This software is dual-licensed to you under the Universal Permissive License
+// (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
+// 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose
+// either license.
 //
-// (ii) the Apache License v 2.0. (http://www.apache.org/licenses/LICENSE-2.0)
+// If you elect to accept the software under the Apache License, Version 2.0,
+// the following applies:
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//    https://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 //-----------------------------------------------------------------------------
 
 //-----------------------------------------------------------------------------
@@ -72,12 +85,11 @@ int dpiTest__clearQueue(dpiTestCase *testCase, dpiConn *conn,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4000_verifyPubFuncsOfQueueWithNull()
+// dpiTest_4000()
 //   Call each of the dpiQueue public functions with the queue parameter set to
 // NULL (error DPI-1002).
 //-----------------------------------------------------------------------------
-int dpiTest_4000_verifyPubFuncsOfQueueWithNull(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4000(dpiTestCase *testCase, dpiTestParams *params)
 {
     const char *expectedError = "DPI-1002:";
 
@@ -111,11 +123,10 @@ int dpiTest_4000_verifyPubFuncsOfQueueWithNull(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4001_releaseQueueTwice()
+// dpiTest_4001()
 //   Create a queue, then call dpiQueue_release() twice (error DPI-1002).
 //-----------------------------------------------------------------------------
-int dpiTest_4001_releaseQueueTwice(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4001(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiQueue *queue;
     dpiConn *conn;
@@ -133,13 +144,12 @@ int dpiTest_4001_releaseQueueTwice(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4002_enqManyWithVariousParameters()
+// dpiTest_4002()
 //   Create a queue and then call dpiQueue_enqMany() without setting any
 // payload (error DPI-1070), with the message properties parameter set to NULL
 // (error DPI-1046) and with the number of properties set to zero (no error).
 //-----------------------------------------------------------------------------
-int dpiTest_4002_enqManyWithVariousParameters(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4002(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiMsgProps *enqProps[NUM_BATCH_ENQ];
     dpiQueue *queue;
@@ -182,13 +192,12 @@ int dpiTest_4002_enqManyWithVariousParameters(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4003_deqManyWithVariousParameters()
+// dpiTest_4003()
 //   Create a queue and then call dpiQueue_deqMany() on an empty queue
 // (no error), number of properties set to 0 (error ORA-25327) and with the
 // different parameters set to NULL (error DPI-1046).
 //-----------------------------------------------------------------------------
-int dpiTest_4003_deqManyWithVariousParameters(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4003(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiMsgProps *deqProps[NUM_BATCH_DEQ];
     dpiDeqOptions *deqOptions;
@@ -238,13 +247,12 @@ int dpiTest_4003_deqManyWithVariousParameters(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4004_enqOneWithVariousParams()
+// dpiTest_4004()
 //   Create a queue and then call dpiQueue_enqOne() without setting a payload
 // (error DPI-1070) and with the different parameters set to NULL (error
 // DPI-1002).
 //-----------------------------------------------------------------------------
-int dpiTest_4004_enqOneWithVariousParams(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4004(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiMsgProps *msgProps;
     dpiQueue *queue;
@@ -278,12 +286,11 @@ int dpiTest_4004_enqOneWithVariousParams(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4005_deqOneWithVariousParams()
+// dpiTest_4005()
 //   Create a queue and then call dpiQueue_deqOne() on an empty queue (no
 // error) and with the different parameters set to null (error DPI-1046).
 //-----------------------------------------------------------------------------
-int dpiTest_4005_deqOneWithVariousParams(dpiTestCase *testCase,
-        dpiTestParams *params)
+int dpiTest_4005(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiDeqOptions *deqOptions;
     dpiMsgProps *props;
@@ -326,11 +333,11 @@ int dpiTest_4005_deqOneWithVariousParams(dpiTestCase *testCase,
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4006_bulkEnqDeq()
+// dpiTest_4006()
 //   Create a queue and then enqueue some messages in batches. Verify that the
 // messages can then be dequeued and match what was enqueued (no error).
 //-----------------------------------------------------------------------------
-int dpiTest_4006_bulkEnqDeq(dpiTestCase *testCase, dpiTestParams *params)
+int dpiTest_4006(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiMsgProps *enqProps[NUM_BATCH_ENQ], *deqProps[NUM_BATCH_DEQ];
     uint32_t i, pos, numMessages, payloadLength;
@@ -423,11 +430,11 @@ int dpiTest_4006_bulkEnqDeq(dpiTestCase *testCase, dpiTestParams *params)
 
 
 //-----------------------------------------------------------------------------
-// dpiTest_4007_bulkEnqDeqObjects()
+// dpiTest_4007()
 //   Create a queue and then enqueue some objects in batches. Verify that the
 // objects can then be dequeued and match what was enqueued (no error).
 //-----------------------------------------------------------------------------
-int dpiTest_4007_bulkEnqDeqObjects(dpiTestCase *testCase, dpiTestParams *params)
+int dpiTest_4007(dpiTestCase *testCase, dpiTestParams *params)
 {
     dpiMsgProps *enqProps[NUM_BATCH_ENQ], *deqProps[NUM_BATCH_DEQ];
     struct bookType books[NUM_MESSAGES] = {
@@ -592,28 +599,114 @@ int dpiTest_4007_bulkEnqDeqObjects(dpiTestCase *testCase, dpiTestParams *params)
 }
 
 
+//-----------------------------------------------------------------------------
+// dpiTest_4008()
+//   Create a queue and then enqueue some messages. Verify that the
+// message can then be dequeued using msgId(no error).
+//-----------------------------------------------------------------------------
+int dpiTest_4008(dpiTestCase *testCase, dpiTestParams *params)
+{
+    const char *payloads[NUM_MESSAGES] = {
+        "The first message",
+        "The second message",
+        "The third message",
+        "The fourth message",
+        "The fifth message",
+        "The sixth message",
+        "The seventh message",
+        "The eighth message",
+        "The ninth message",
+        "The tenth message",
+        "The eleventh message",
+        "The twelfth and final message"
+    };
+    dpiDeqOptions *deqOptions;
+    uint32_t payloadLength;
+    dpiMsgProps *msgProps;
+    const char *payload;
+    const char *msg;
+    uint32_t msgLen;
+    dpiQueue *queue;
+    dpiConn *conn;
+    uint32_t i;
+
+    // connect to database
+    if (dpiTestCase_getConnection(testCase, &conn) < 0)
+        return DPI_FAILURE;
+    if (dpiTest__clearQueue(testCase, conn, RAW_QUEUE_NAME, NULL) < 0)
+        return DPI_FAILURE;
+    if (dpiConn_newQueue(conn, RAW_QUEUE_NAME, strlen(RAW_QUEUE_NAME), NULL,
+            &queue) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiConn_newMsgProps(conn, &msgProps) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+
+    // enqueue messages
+    for (i = 0; i < NUM_MESSAGES; i++) {
+        if (dpiMsgProps_setPayloadBytes(msgProps, payloads[i],
+                strlen(payloads[i])) < 0)
+            return dpiTestCase_setFailedFromError(testCase);
+        if (dpiQueue_enqOne(queue, msgProps) < 0)
+            return dpiTestCase_setFailedFromError(testCase);
+    }
+
+    if (dpiMsgProps_getMsgId(msgProps, &msg, &msgLen) < 0)
+            return dpiTestCase_setFailedFromError(testCase);
+
+    // get dequeue options from queue and set some options
+    if (dpiQueue_getDeqOptions(queue, &deqOptions) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiDeqOptions_setNavigation(deqOptions, DPI_DEQ_NAV_FIRST_MSG) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiDeqOptions_setWait(deqOptions, DPI_DEQ_WAIT_NO_WAIT) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiDeqOptions_setMsgId(deqOptions, msg, msgLen) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiMsgProps_release(msgProps) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiQueue_deqOne(queue, &msgProps) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiMsgProps_getPayload(msgProps, NULL, &payload,
+            &payloadLength) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiTestCase_expectStringEqual(testCase, payload, payloadLength,
+            payloads[NUM_MESSAGES - 1],
+            strlen(payloads[NUM_MESSAGES - 1])) < 0)
+        return DPI_FAILURE;
+
+    // cleanup
+    if (dpiQueue_release(queue) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+    if (dpiMsgProps_release(msgProps) < 0)
+        return dpiTestCase_setFailedFromError(testCase);
+
+    return DPI_SUCCESS;
+}
+
 //-----------------------------------------------------------------------------
 // main()
 //-----------------------------------------------------------------------------
 int main(int argc, char **argv)
 {
     dpiTestSuite_initialize(4000);
-    dpiTestSuite_addCase(dpiTest_4000_verifyPubFuncsOfQueueWithNull,
+    dpiTestSuite_addCase(dpiTest_4000,
             "call public functions with queue set to NULL");
-    dpiTestSuite_addCase(dpiTest_4001_releaseQueueTwice,
+    dpiTestSuite_addCase(dpiTest_4001,
             "call dpiQueue_release() twice");
-    dpiTestSuite_addCase(dpiTest_4002_enqManyWithVariousParameters,
+    dpiTestSuite_addCase(dpiTest_4002,
             "call dpiQueue_enqMany() with various parameters");
-    dpiTestSuite_addCase(dpiTest_4003_deqManyWithVariousParameters,
+    dpiTestSuite_addCase(dpiTest_4003,
             "call dpiQueue_deqMany() with various parameters");
-    dpiTestSuite_addCase(dpiTest_4004_enqOneWithVariousParams,
+    dpiTestSuite_addCase(dpiTest_4004,
             "call dpiQueue_enqOne() with various parameters");
-    dpiTestSuite_addCase(dpiTest_4005_deqOneWithVariousParams,
+    dpiTestSuite_addCase(dpiTest_4005,
             "call dpiQueue_deqOne() with various parameters");
-    dpiTestSuite_addCase(dpiTest_4006_bulkEnqDeq,
+    dpiTestSuite_addCase(dpiTest_4006,
             "bulk dequeue of raw data matches what was enqueued");
-    dpiTestSuite_addCase(dpiTest_4007_bulkEnqDeqObjects,
+    dpiTestSuite_addCase(dpiTest_4007,
             "bulk dequeue of objects matches what was enqueued");
+    dpiTestSuite_addCase(dpiTest_4008,
+            "verify dequeue by message id");
 
     return dpiTestSuite_run();
 }
